@@ -4,6 +4,7 @@
 use strict; use warnings;
 package Lingy::Lang::Class;
 
+use Lingy::Common;
 
 # This section is base class support for all Lingy object classes.
 # They all inherit from this:
@@ -57,4 +58,11 @@ sub _name {
     return $name;
 }
 
+# Public methods:
+sub isInstance {
+    my ($base_class, $instance) = @_;
+    my $instance_class = ref($instance);
+    $instance->isa($base_class) ? true : false;
+}
+
 1;
